@@ -522,16 +522,7 @@ proto._dotop = function(root, item, args, lvalue) {
             } else {
                 return root[item];
             }
-        } /*
-        	//this section was for automatic global scope access
-        	else if (atroot && typeof this.data.GLOBAL[item] != 'undefined' && this.__config__.GLOBAL && item != 'LOCAL' ) {
-            
-            if (typeof this.data.GLOBAL[item] == 'function' ) {
-                result = this.data.GLOBAL[item].apply(root,args);
-            } else {
-                return this.data.GLOBAL[item];
-            }
-        }*/ else if (lvalue) {
+        } else if (lvalue) {
             return root[item] = {};
         } else if (this.hash_functions[item] && !atroot || item == 'import') {
             args.unshift(root);
@@ -553,48 +544,7 @@ proto._dotop = function(root, item, args, lvalue) {
             for (var i = 0; i < item.length; i++) result.push(root[item[i]]);
             return result;
         }
-    } /*else if ( (root.constructor != Object) && (root instanceof Object) ) {
-        //this section was proposed for calling method on blessed reference in Perl
-		//not sure how well it is playing with javascript
-		try {
-            result = root[item].apply(root,args);
-        } catch (e) {
-            var my_class = root.constructor.name;
-            
-            if (false) throw "Cant locate method"; 
-            
-            if (root instanceof Array) {
-                if (this.list_functions[item]) {
-                    args.unshift(root);
-                    result = this.list_functions[item].apply(this,args);
-                } else if (typeof item == 'string' && /^-?\d+$/.test(item) || typeof item == 'number' ) {
-                    if (typeof root[item] != 'function') return root[item];
-                    result = root[item].apply(this, args);
-                } else if (item instanceof Array) {
-                    for (var i = 0; i < item.length; i++) result.push(root[item[i]]);
-                    return result;
-                }
-            } else if (typeof root == 'object') {
-                if (typeof root[item] != 'undefined' && root[item] != null) {//consider undefined == null
-                    if (typeof root[item] == 'function') {
-                        result = root[item].apply(this,args);
-                    } else {
-                        return root[item];
-                    }
-                } else if (this.hash_functions[item]) {
-                    args.unshift(root);
-                    result = this.hash_functions[item].apply(this,args);
-                } 
-            } else if (this.string_functions[item]) {
-                args.unshift(root);
-                result = this.string_functions[item].apply(this, args);
-            } else if (this.list_functions[item]) {
-                args.unshift([root]);
-                result = this.list_functions[item].apply(this,args);
-            } 
-            
-        }
-    }*/ else if (this.string_functions[item] && !lvalue) {
+    } else if (this.string_functions[item] && !lvalue) {
         args.unshift(root);
         result = this.string_functions[item].apply(this, args);
     } else if (this.list_functions[item] && !lvalue) {
@@ -627,10 +577,6 @@ proto._assign = function(root, item, args, value, set_default) {
     }
     
     if (atroot || root.constructor == Object || root == this.data.GLOBAL) {
-//this section was for automatic global scope access    	
-//		if (atroot && this.__config__.GLOBAL && typeof root[item] == 'undefined' && typeof this.data.GLOBAL[item] != 'undefined' && !set_default) { 
-//            return this.data.GLOBAL[item] = value;
-//        }
 		
 		if (root == this.LOCAL_ANCHOR) root = this.data;
 			 
@@ -705,7 +651,7 @@ proto.string_functions.list = function(string) {
 
 // match(re)       get list of matches
 proto.string_functions.match = function(string, re, modifiers) {
-    var regexp = new RegExp(re, modifiers);
+    var regexp = new RegExp(re, modifiers == undefined ? 'g' : modifiers);
     var list = string.match(regexp);
     return list;
 }
@@ -722,7 +668,7 @@ proto.string_functions.repeat = function(string, args) {
 
 // replace(re, sub, global)    replace instances of re with sub
 proto.string_functions.replace = function(string, re, sub, modifiers) {
-    var regexp = new RegExp(re,modifiers);    
+    var regexp = new RegExp(re, modifiers == undefined ? 'g' : modifiers);    
     if (! sub) sub  = '';
 
     return string.replace(regexp, sub);
@@ -982,6 +928,20 @@ proto.hash_functions.values = function(hash) {
     return list;
 }
 
+proto.hash_functions.pairs = function(hash) {
+    var list = new Array();
+    var keys = new Array();
+    for ( var key in hash ) {
+        keys.push( key );
+    }
+    keys.sort();
+    for ( var key in keys ) {
+        key = keys[key]
+        list.push( { 'key': key, 'value': hash[key] } );
+    }
+    return list;
+}
+
 //  delete
 proto.hash_functions.remove = function(hash, key) {
     return delete hash[key];
@@ -1088,8 +1048,8 @@ Jemplate.JSON = {
 }());
 
 ;/*
-    json2.js
-    2008-03-24
+    http://www.JSON.org/json2.js
+    2009-04-16
 
     Public Domain.
 
@@ -1097,44 +1057,48 @@ Jemplate.JSON = {
 
     See http://www.JSON.org/js.html
 
-    This file creates a global JSON object containing three methods: stringify,
-    parse, and quote.
-
+    This file creates a global JSON object containing two methods: stringify
+    and parse.
 
         JSON.stringify(value, replacer, space)
             value       any JavaScript value, usually an object or array.
 
             replacer    an optional parameter that determines how object
-                        values are stringified for objects without a toJSON
-                        method. It can be a function or an array.
+                        values are stringified for objects. It can be a
+                        function or an array of strings.
 
             space       an optional parameter that specifies the indentation
                         of nested structures. If it is omitted, the text will
                         be packed without extra whitespace. If it is a number,
                         it will specify the number of spaces to indent at each
-                        level. If it is a string (such as '\t'), it contains the
-                        characters used to indent at each level.
+                        level. If it is a string (such as '\t' or '&nbsp;'),
+                        it contains the characters used to indent at each level.
 
             This method produces a JSON text from a JavaScript value.
 
             When an object value is found, if the object contains a toJSON
-            method, its toJSON method with be called and the result will be
+            method, its toJSON method will be called and the result will be
             stringified. A toJSON method does not serialize: it returns the
             value represented by the name/value pair that should be serialized,
-            or undefined if nothing should be serialized. The toJSON method will
-            be passed the key associated with the value, and this will be bound
-            to the object holding the key.
+            or undefined if nothing should be serialized. The toJSON method
+            will be passed the key associated with the value, and this will be
+            bound to the object holding the key.
 
-            This is the toJSON method added to Dates:
+            For example, this would serialize Dates as ISO strings.
+
+                Date.prototype.toJSON = function (key) {
+                    function f(n) {
+                        // Format integers to have at least two digits.
+                        return n < 10 ? '0' + n : n;
+                    }
 
-                function toJSON(key) {
                     return this.getUTCFullYear()   + '-' +
                          f(this.getUTCMonth() + 1) + '-' +
                          f(this.getUTCDate())      + 'T' +
                          f(this.getUTCHours())     + ':' +
                          f(this.getUTCMinutes())   + ':' +
                          f(this.getUTCSeconds())   + 'Z';
-                }
+                };
 
             You can provide an optional replacer method. It will be passed the
             key and value of each member, with this bound to the containing
@@ -1142,35 +1106,24 @@ Jemplate.JSON = {
             serialized. If your method returns undefined, then the member will
             be excluded from the serialization.
 
-            If no replacer parameter is provided, then a default replacer
-            will be used:
-
-                function replacer(key, value) {
-                    return Object.hasOwnProperty.call(this, key) ?
-                        value : undefined;
-                }
-
-            The default replacer is passed the key and value for each item in
-            the structure. It excludes inherited members.
-
-            If the replacer parameter is an array, then it will be used to
-            select the members to be serialized. It filters the results such
-            that only members with keys listed in the replacer array are
+            If the replacer parameter is an array of strings, then it will be
+            used to select the members to be serialized. It filters the results
+            such that only members with keys listed in the replacer array are
             stringified.
 
-            Values that do not have JSON representaions, such as undefined or
+            Values that do not have JSON representations, such as undefined or
             functions, will not be serialized. Such values in objects will be
             dropped; in arrays they will be replaced with null. You can use
             a replacer function to replace those with JSON values.
             JSON.stringify(undefined) returns undefined.
 
-            The optional space parameter produces a stringification of the value
-            that is filled with line breaks and indentation to make it easier to
-            read.
+            The optional space parameter produces a stringification of the
+            value that is filled with line breaks and indentation to make it
+            easier to read.
 
             If the space parameter is a non-empty string, then that string will
             be used for indentation. If the space parameter is a number, then
-            then indentation will be that many spaces.
+            the indentation will be that many spaces.
 
             Example:
 
@@ -1181,16 +1134,22 @@ Jemplate.JSON = {
             text = JSON.stringify(['e', {pluribus: 'unum'}], null, '\t');
             // text is '[\n\t"e",\n\t{\n\t\t"pluribus": "unum"\n\t}\n]'
 
+            text = JSON.stringify([new Date()], function (key, value) {
+                return this[key] instanceof Date ?
+                    'Date(' + this[key] + ')' : value;
+            });
+            // text is '["Date(---current time---)"]'
+
 
         JSON.parse(text, reviver)
             This method parses a JSON text to produce an object or array.
             It can throw a SyntaxError exception.
 
             The optional reviver parameter is a function that can filter and
-            transform the results. It receives each of the keys and values, and
-            its return value is used instead of the original value. If it
-            returns what it received, then structure is not modified. If it
-            returns undefined then the member is deleted.
+            transform the results. It receives each of the keys and values,
+            and its return value is used instead of the original value.
+            If it returns what it received, then the structure is not modified.
+            If it returns undefined then the member is deleted.
 
             Example:
 
@@ -1210,45 +1169,57 @@ Jemplate.JSON = {
                 return value;
             });
 
-
-        JSON.quote(text)
-            This method wraps a string in quotes, escaping some characters
-            as needed.
+            myData = JSON.parse('["Date(09/09/2001)"]', function (key, value) {
+                var d;
+                if (typeof value === 'string' &&
+                        value.slice(0, 5) === 'Date(' &&
+                        value.slice(-1) === ')') {
+                    d = new Date(value.slice(5, -1));
+                    if (d) {
+                        return d;
+                    }
+                }
+                return value;
+            });
 
 
     This is a reference implementation. You are free to copy, modify, or
     redistribute.
 
-    USE YOUR OWN COPY. IT IS EXTREMELY UNWISE TO LOAD THIRD PARTY
-    CODE INTO YOUR PAGES.
+    This code should be minified before deployment.
+    See http://javascript.crockford.com/jsmin.html
+
+    USE YOUR OWN COPY. IT IS EXTREMELY UNWISE TO LOAD CODE FROM SERVERS YOU DO
+    NOT CONTROL.
 */
 
-/*jslint regexp: true, forin: true, evil: true */
+/*jslint evil: true */
 
 /*global JSON */
 
 /*members "", "\b", "\t", "\n", "\f", "\r", "\"", JSON, "\\", apply,
-    call, charCodeAt, floor, getUTCDate, getUTCFullYear, getUTCHours,
-    getUTCMinutes, getUTCMonth, getUTCSeconds, hasOwnProperty, join, length,
-    parse, propertyIsEnumerable, prototype, push, quote, replace, stringify,
-    test, toJSON, toString
+    call, charCodeAt, getUTCDate, getUTCFullYear, getUTCHours,
+    getUTCMinutes, getUTCMonth, getUTCSeconds, hasOwnProperty, join,
+    lastIndex, length, parse, prototype, push, replace, slice, stringify,
+    test, toJSON, toString, valueOf
 */
 
-if (!JSON) var JSON;
-if (!JSON) {
-
 // Create a JSON object only if one does not already exist. We create the
-// object in a closure to avoid global variables.
+// methods in a closure to avoid creating global variables.
 
-    JSON = function () {
+if (!this.JSON) {
+    this.JSON = {};
+}
+(function () {
 
-        function f(n) {    // Format integers to have at least two digits.
-            return n < 10 ? '0' + n : n;
-        }
+    function f(n) {
+        // Format integers to have at least two digits.
+        return n < 10 ? '0' + n : n;
+    }
 
-        Date.prototype.toJSON = function () {
+    if (typeof Date.prototype.toJSON !== 'function') {
 
-// Eventually, this method will be based on the date.toISOString method.
+        Date.prototype.toJSON = function (key) {
 
             return this.getUTCFullYear()   + '-' +
                  f(this.getUTCMonth() + 1) + '-' +
@@ -1258,175 +1229,179 @@ if (!JSON) {
                  f(this.getUTCSeconds())   + 'Z';
         };
 
+        String.prototype.toJSON =
+        Number.prototype.toJSON =
+        Boolean.prototype.toJSON = function (key) {
+            return this.valueOf();
+        };
+    }
 
-        var escapeable = /["\\\x00-\x1f\x7f-\x9f]/g,
-            gap,
-            indent,
-            meta = {    // table of character substitutions
-                '\b': '\\b',
-                '\t': '\\t',
-                '\n': '\\n',
-                '\f': '\\f',
-                '\r': '\\r',
-                '"' : '\\"',
-                '\\': '\\\\'
-            },
-            rep;
+    var cx = /[\u0000\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,
+        escapable = /[\\\"\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,
+        gap,
+        indent,
+        meta = {    // table of character substitutions
+            '\b': '\\b',
+            '\t': '\\t',
+            '\n': '\\n',
+            '\f': '\\f',
+            '\r': '\\r',
+            '"' : '\\"',
+            '\\': '\\\\'
+        },
+        rep;
 
 
-        function quote(string) {
+    function quote(string) {
 
 // If the string contains no control characters, no quote characters, and no
 // backslash characters, then we can safely slap some quotes around it.
 // Otherwise we must also replace the offending characters with safe escape
 // sequences.
 
-            return escapeable.test(string) ?
-                '"' + string.replace(escapeable, function (a) {
-                    var c = meta[a];
-                    if (typeof c === 'string') {
-                        return c;
-                    }
-                    c = a.charCodeAt();
-                    return '\\u00' + Math.floor(c / 16).toString(16) +
-                                               (c % 16).toString(16);
-                }) + '"' :
-                '"' + string + '"';
-        }
+        escapable.lastIndex = 0;
+        return escapable.test(string) ?
+            '"' + string.replace(escapable, function (a) {
+                var c = meta[a];
+                return typeof c === 'string' ? c :
+                    '\\u' + ('0000' + a.charCodeAt(0).toString(16)).slice(-4);
+            }) + '"' :
+            '"' + string + '"';
+    }
 
 
-        function str(key, holder) {
+    function str(key, holder) {
 
 // Produce a string from holder[key].
 
-            var i,          // The loop counter.
-                k,          // The member key.
-                v,          // The member value.
-                length,
-                mind = gap,
-                partial,
-                value = holder[key];
+        var i,          // The loop counter.
+            k,          // The member key.
+            v,          // The member value.
+            length,
+            mind = gap,
+            partial,
+            value = holder[key];
 
 // If the value has a toJSON method, call it to obtain a replacement value.
 
-            if (value && typeof value === 'object' &&
-                    typeof value.toJSON === 'function') {
-                value = value.toJSON(key);
-            }
+        if (value && typeof value === 'object' &&
+                typeof value.toJSON === 'function') {
+            value = value.toJSON(key);
+        }
 
 // If we were called with a replacer function, then call the replacer to
 // obtain a replacement value.
 
-            if (typeof rep === 'function') {
-                value = rep.call(holder, key, value);
-            }
+        if (typeof rep === 'function') {
+            value = rep.call(holder, key, value);
+        }
 
 // What happens next depends on the value's type.
 
-            switch (typeof value) {
-            case 'string':
-                return quote(value);
+        switch (typeof value) {
+        case 'string':
+            return quote(value);
 
-            case 'number':
+        case 'number':
 
 // JSON numbers must be finite. Encode non-finite numbers as null.
 
-                return isFinite(value) ? String(value) : 'null';
+            return isFinite(value) ? String(value) : 'null';
 
-            case 'boolean':
-            case 'null':
+        case 'boolean':
+        case 'null':
 
 // If the value is a boolean or null, convert it to a string. Note:
 // typeof null does not produce 'null'. The case is included here in
 // the remote chance that this gets fixed someday.
 
-                return String(value);
+            return String(value);
 
 // If the type is 'object', we might be dealing with an object or an array or
 // null.
 
-            case 'object':
+        case 'object':
 
 // Due to a specification blunder in ECMAScript, typeof null is 'object',
 // so watch out for that case.
 
-                if (!value) {
-                    return 'null';
-                }
+            if (!value) {
+                return 'null';
+            }
 
 // Make an array to hold the partial results of stringifying this object value.
 
-                gap += indent;
-                partial = [];
+            gap += indent;
+            partial = [];
 
-// If the object has a dontEnum length property, we'll treat it as an array.
+// Is the value an array?
 
-                if (typeof value.length === 'number' &&
-                        !(value.propertyIsEnumerable('length'))) {
+            if (Object.prototype.toString.apply(value) === '[object Array]') {
 
-// The object is an array. Stringify every element. Use null as a placeholder
+// The value is an array. Stringify every element. Use null as a placeholder
 // for non-JSON values.
 
-                    length = value.length;
-                    for (i = 0; i < length; i += 1) {
-                        partial[i] = str(i, value) || 'null';
-                    }
+                length = value.length;
+                for (i = 0; i < length; i += 1) {
+                    partial[i] = str(i, value) || 'null';
+                }
 
 // Join all of the elements together, separated with commas, and wrap them in
 // brackets.
 
-                    v = partial.length === 0 ? '[]' :
-                        gap ? '[\n' + gap + partial.join(',\n' + gap) +
-                                  '\n' + mind + ']' :
-                              '[' + partial.join(',') + ']';
-                    gap = mind;
-                    return v;
-                }
+                v = partial.length === 0 ? '[]' :
+                    gap ? '[\n' + gap +
+                            partial.join(',\n' + gap) + '\n' +
+                                mind + ']' :
+                          '[' + partial.join(',') + ']';
+                gap = mind;
+                return v;
+            }
 
 // If the replacer is an array, use it to select the members to be stringified.
 
-                if (typeof rep === 'object') {
-                    length = rep.length;
-                    for (i = 0; i < length; i += 1) {
-                        k = rep[i];
-                        if (typeof k === 'string') {
-                            v = str(k, value, rep);
-                            if (v) {
-                                partial.push(quote(k) + (gap ? ': ' : ':') + v);
-                            }
-                        }
-                    }
-                } else {
-
-// Otherwise, iterate through all of the keys in the object.
-
-                    for (k in value) {
-                        v = str(k, value, rep);
+            if (rep && typeof rep === 'object') {
+                length = rep.length;
+                for (i = 0; i < length; i += 1) {
+                    k = rep[i];
+                    if (typeof k === 'string') {
+                        v = str(k, value);
                         if (v) {
                             partial.push(quote(k) + (gap ? ': ' : ':') + v);
                         }
                     }
                 }
+            } else {
+
+// Otherwise, iterate through all of the keys in the object.
+
+                for (k in value) {
+                    if (Object.hasOwnProperty.call(value, k)) {
+                        v = str(k, value);
+                        if (v) {
+                            partial.push(quote(k) + (gap ? ': ' : ':') + v);
+                        }
+                    }
+                }
+            }
 
 // Join all of the member texts together, separated with commas,
 // and wrap them in braces.
 
-                v = partial.length === 0 ? '{}' :
-                    gap ? '{\n' + gap + partial.join(',\n' + gap) +
-                              '\n' + mind + '}' :
-                          '{' + partial.join(',') + '}';
-                gap = mind;
-                return v;
-            }
-
-            return null;
+            v = partial.length === 0 ? '{}' :
+                gap ? '{\n' + gap + partial.join(',\n' + gap) + '\n' +
+                        mind + '}' : '{' + partial.join(',') + '}';
+            gap = mind;
+            return v;
         }
 
+        return '';
+    }
 
-// Return the JSON object containing the stringify, parse, and quote methods.
+// If the JSON object does not yet have a stringify method, give it one.
 
-        return {
-            stringify: function (value, replacer, space) {
+    if (typeof JSON.stringify !== 'function') {
+        JSON.stringify = function (value, replacer, space) {
 
 // The stringify method takes a value and an optional replacer, and an optional
 // space parameter, and returns a JSON text. The replacer can be a function
@@ -1434,123 +1409,124 @@ if (!JSON) {
 // A default replacer method can be provided. Use of the space parameter can
 // produce text that is more easily readable.
 
-                var i;
-                gap = '';
-                indent = '';
-                if (space) {
+            var i;
+            gap = '';
+            indent = '';
 
 // If the space parameter is a number, make an indent string containing that
 // many spaces.
 
-                    if (typeof space === 'number') {
-                        for (i = 0; i < space; i += 1) {
-                            indent += ' ';
-                        }
+            if (typeof space === 'number') {
+                for (i = 0; i < space; i += 1) {
+                    indent += ' ';
+                }
 
 // If the space parameter is a string, it will be used as the indent string.
 
-                    } else if (typeof space === 'string') {
-                        indent = space;
-                    }
-                }
+            } else if (typeof space === 'string') {
+                indent = space;
+            }
 
-// If there is no replacer parameter, use the default replacer.
+// If there is a replacer, it must be a function or an array.
+// Otherwise, throw an error.
 
-                if (!replacer) {
-                    rep = function (key, value) {
-                        if (!Object.hasOwnProperty.call(this, key)) {
-                            return undefined;
-                        }
-                        return value;
-                    };
-
-// The replacer can be a function or an array. Otherwise, throw an error.
-
-                } else if (typeof replacer === 'function' ||
-                        (typeof replacer === 'object' &&
-                         typeof replacer.length === 'number')) {
-                    rep = replacer;
-                } else {
-                    throw new Error('JSON.stringify');
-                }
+            rep = replacer;
+            if (replacer && typeof replacer !== 'function' &&
+                    (typeof replacer !== 'object' ||
+                     typeof replacer.length !== 'number')) {
+                throw new Error('JSON.stringify');
+            }
 
 // Make a fake root object containing our value under the key of ''.
 // Return the result of stringifying the value.
 
-                return str('', {'': value});
-            },
+            return str('', {'': value});
+        };
+    }
 
 
-            parse: function (text, reviver) {
+// If the JSON object does not yet have a parse method, give it one.
+
+    if (typeof JSON.parse !== 'function') {
+        JSON.parse = function (text, reviver) {
 
 // The parse method takes a text and an optional reviver function, and returns
 // a JavaScript value if the text is a valid JSON text.
 
-                var j;
+            var j;
 
-                function walk(holder, key) {
+            function walk(holder, key) {
 
 // The walk method is used to recursively walk the resulting structure so
 // that modifications can be made.
 
-                    var k, v, value = holder[key];
-                    if (value && typeof value === 'object') {
-                        for (k in value) {
-                            if (Object.hasOwnProperty.call(value, k)) {
-                                v = walk(value, k);
-                                if (v !== undefined) {
-                                    value[k] = v;
-                                } else {
-                                    delete value[k];
-                                }
+                var k, v, value = holder[key];
+                if (value && typeof value === 'object') {
+                    for (k in value) {
+                        if (Object.hasOwnProperty.call(value, k)) {
+                            v = walk(value, k);
+                            if (v !== undefined) {
+                                value[k] = v;
+                            } else {
+                                delete value[k];
                             }
                         }
                     }
-                    return reviver.call(holder, key, value);
                 }
+                return reviver.call(holder, key, value);
+            }
 
 
-// Parsing happens in three stages. In the first stage, we run the text against
-// regular expressions that look for non-JSON patterns. We are especially
-// concerned with '()' and 'new' because they can cause invocation, and '='
-// because it can cause mutation. But just to be safe, we want to reject all
-// unexpected forms.
+// Parsing happens in four stages. In the first stage, we replace certain
+// Unicode characters with escape sequences. JavaScript handles many characters
+// incorrectly, either silently deleting them, or treating them as line endings.
 
-// We split the first stage into 4 regexp operations in order to work around
+            cx.lastIndex = 0;
+            if (cx.test(text)) {
+                text = text.replace(cx, function (a) {
+                    return '\\u' +
+                        ('0000' + a.charCodeAt(0).toString(16)).slice(-4);
+                });
+            }
+
+// In the second stage, we run the text against regular expressions that look
+// for non-JSON patterns. We are especially concerned with '()' and 'new'
+// because they can cause invocation, and '=' because it can cause mutation.
+// But just to be safe, we want to reject all unexpected forms.
+
+// We split the second stage into 4 regexp operations in order to work around
 // crippling inefficiencies in IE's and Safari's regexp engines. First we
-// replace all backslash pairs with '@' (a non-JSON character). Second, we
+// replace the JSON backslash pairs with '@' (a non-JSON character). Second, we
 // replace all simple value tokens with ']' characters. Third, we delete all
 // open brackets that follow a colon or comma or that begin the text. Finally,
 // we look to see that the remaining characters are only whitespace or ']' or
 // ',' or ':' or '{' or '}'. If that is so, then the text is safe for eval.
 
-                if (/^[\],:{}\s]*$/.test(text.replace(/\\["\\\/bfnrtu]/g, '@').
+            if (/^[\],:{}\s]*$/.
+test(text.replace(/\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})/g, '@').
 replace(/"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g, ']').
 replace(/(?:^|:|,)(?:\s*\[)+/g, ''))) {
 
-// In the second stage we use the eval function to compile the text into a
+// In the third stage we use the eval function to compile the text into a
 // JavaScript structure. The '{' operator is subject to a syntactic ambiguity
 // in JavaScript: it can begin a block or an object literal. We wrap the text
 // in parens to eliminate the ambiguity.
 
-                    j = eval('(' + text + ')');
+                j = eval('(' + text + ')');
 
-// In the optional third stage, we recursively walk the new structure, passing
+// In the optional fourth stage, we recursively walk the new structure, passing
 // each name/value pair to a reviver function for possible transformation.
 
-                    return typeof reviver === 'function' ?
-                        walk({'': j}, '') : j;
-                }
+                return typeof reviver === 'function' ?
+                    walk({'': j}, '') : j;
+            }
 
 // If the text is not JSON parseable, then a SyntaxError is thrown.
 
-                throw new SyntaxError('JSON.parse');
-            },
-
-            quote: quote
+            throw new SyntaxError('JSON.parse');
         };
-    }();
-}
+    }
+}());
 
 ;;(function(){
 
